library(foreign)

## a function to compute rates from weighted data
compute.prob <- function(weights, num, den) {
  return (sum(weights[num], na.rm = TRUE)/sum(weights[den], na.rm = TRUE))
}

######## Data for 2005 ########

## open dataset
data2005 <- read.spss("PPCS - 2005.sav", add.undeclared.levels="no", to.data.frame = TRUE)

## keep only men and subset data by race and Hispanic origin
white2005 <- data2005[data2005$V5 == "White only" & data2005$V6 == "No" & data2005$V3 == "Male", ]
black2005 <- data2005[data2005$V5 == "Black only" & data2005$V6 == "No" & data2005$V3 == "Male", ]
hisp2005 <- data2005[data2005$V6 == "Yes" & data2005$V3 == "Male", ]

## subset data by sex
men2005 <- data2005[data2005$V3 == "Male", ]
women2005 <- data2005[data2005$V3 == "Female", ]

## probability of having at least one contact in the past 12 months by race
white.prob.contact2005 <- compute.prob(white2005$WEIGHT, white2005$V10 == "Yes", !is.na(white2005$V10))
black.prob.contact2005 <- compute.prob(black2005$WEIGHT, black2005$V10 == "Yes", !is.na(black2005$V10))
hisp.prob.contact2005 <- compute.prob(hisp2005$WEIGHT, hisp2005$V10 == "Yes", !is.na(hisp2005$V10))

## probability of having at least one contact in the past 12 months by sex
men.prob.contact2005 <- compute.prob(men2005$WEIGHT, men2005$V10 == "Yes", !is.na(men2005$V10))
women.prob.contact2005 <- compute.prob(women2005$WEIGHT, women2005$V10 == "Yes", !is.na(women2005$V10))

## mean number of contacts by race for people who had at least one contact
white.mean.contacts2005 <- weighted.mean(white2005$V11[white2005$V11 != 0], white2005$WEIGHT[white2005$V11 != 0], na.rm = TRUE)
black.mean.contacts2005 <- weighted.mean(black2005$V11[black2005$V11 != 0], black2005$WEIGHT[black2005$V11 != 0], na.rm = TRUE)
hisp.mean.contacts2005 <- weighted.mean(hisp2005$V11[hisp2005$V11 != 0], hisp2005$WEIGHT[hisp2005$V11 != 0], na.rm = TRUE)

## probability of having more than 3 contacts in the past 12 months by race for people who had at least one contact
white.prob.3contacts2005 <- compute.prob(white2005$WEIGHT, white2005$V11 > 3, !is.na(white2005$V11))
black.prob.3contacts2005 <- compute.prob(black2005$WEIGHT, black2005$V11 > 3, !is.na(black2005$V11))
hisp.prob.3contacts2005 <- compute.prob(hisp2005$WEIGHT, hisp2005$V11 > 3, !is.na(hisp2005$V11))

## probability that police used or threatened to use force during last contact for people who had at least one contact
white.prob.force2005 <- compute.prob(white2005$WEIGHT, white2005$V12 == "Yes", !is.na(white2005$V12))
black.prob.force2005 <- compute.prob(black2005$WEIGHT, black2005$V12 == "Yes", !is.na(black2005$V12))
hisp.prob.force2005 <- compute.prob(hisp2005$WEIGHT, hisp2005$V12 == "Yes", !is.na(hisp2005$V12))

## probability that police used or threatened to use force during last contact for people who had at least one contact
## broken down by sex instead of race
men.prob.force2005 <- compute.prob(men2005$WEIGHT, men2005$V12 == "Yes", !is.na(men2005$V12))
women.prob.force2005 <- compute.prob(women2005$WEIGHT, women2005$V12 == "Yes", !is.na(women2005$V12))

## probability that police used verbal force during last contact for people
## against whom the police used or threatened to use force
white.prob.verbal2005 <- compute.prob(white2005$WEIGHT,
                                      white2005$V15 == "Shout or curse" | white2005$V16 == "Threatened force",
                                      white2005$V12 == "Yes")
black.prob.verbal2005 <- compute.prob(black2005$WEIGHT,
                                      black2005$V15 == "Shout or curse" | black2005$V16 == "Threatened force",
                                      black2005$V12 == "Yes")
hisp.prob.verbal2005 <- compute.prob(hisp2005$WEIGHT,
                                     hisp2005$V15 == "Shout or curse" | hisp2005$V16 == "Threatened force",
                                     hisp2005$V12 == "Yes")

## probability that police used physical force during last contact for people
## against whom the police used or threatened to use force
white.prob.physical2005 <- compute.prob(white2005$WEIGHT,
                                        white2005$V17 == "Push or grab" | white2005$V18 == "Kick or hit" | white2005$V19 == "Use pepper spray" | white2005$V20 == "Point gun",
                                        white2005$V12 == "Yes")
black.prob.physical2005 <- compute.prob(black2005$WEIGHT,
                                        black2005$V17 == "Push or grab" | black2005$V18 == "Kick or hit" | black2005$V19 == "Use pepper spray" | black2005$V20 == "Point gun",
                                        black2005$V12 == "Yes")
hisp.prob.physical2005 <- compute.prob(hisp2005$WEIGHT,
                                       hisp2005$V17 == "Push or grab" | hisp2005$V18 == "Kick or hit" | hisp2005$V19 == "Use pepper spray" | hisp2005$V20 == "Point gun",
                                       hisp2005$V12 == "Yes")

## probability that police used physical force during last contact for people
## against whom the police used or threatened to use force broken down by sex
men.prob.physical2005 <- compute.prob(men2005$WEIGHT,
                                        men2005$V17 == "Push or grab" | men2005$V18 == "Kick or hit" | men2005$V19 == "Use pepper spray" | men2005$V20 == "Point gun",
                                        men2005$V12 == "Yes")
women.prob.physical2005 <- compute.prob(women2005$WEIGHT,
                                        women2005$V17 == "Push or grab" | women2005$V18 == "Kick or hit" | women2005$V19 == "Use pepper spray" | women2005$V20 == "Point gun",
                                        women2005$V12 == "Yes")

## probability that respondent was injured during last contact for people who had at least one contact
## during which the police used or threatened to use force against them
white.prob.injured2005 <- compute.prob(white2005$WEIGHT,
                                       white2005$INJURED == "Yes",
                                       !is.na(white2005$INJURED))
black.prob.injured2005 <- compute.prob(black2005$WEIGHT,
                                       black2005$INJURED == "Yes",
                                       !is.na(black2005$INJURED))
hisp.prob.injured2005 <- compute.prob(hisp2005$WEIGHT,
                                      hisp2005$INJURED == "Yes",
                                      !is.na(hisp2005$INJURED))

## probability that respondent was injured during last contact for people who had at least one contact
## during which the police used or threatened to use force against them broken down by sex instead of race
men.prob.injured2005 <- compute.prob(men2005$WEIGHT,
                                       men2005$INJURED == "Yes",
                                       !is.na(men2005$INJURED))
women.prob.injured2005 <- compute.prob(women2005$WEIGHT,
                                       women2005$INJURED == "Yes",
                                       !is.na(women2005$INJURED))

######## Data for 2008 ########

## open dataset
data2008 <- read.spss("PPCS - 2008.sav", add.undeclared.levels="no", to.data.frame = TRUE)

## keep only men and subset respondents by race and Hispanic origin
white2008 <- data2008[data2008$RACEHISP == "White" & data2008$SEX == "Male", ]
black2008 <- data2008[data2008$RACEHISP == "Black" & data2008$SEX == "Male", ]
hisp2008 <- data2008[data2008$RACEHISP == "Hispanic" & data2008$SEX == "Male", ]

## subset respondents by sex
men2008 <- data2008[data2008$SEX == "Male", ]
women2008 <- data2008[data2008$SEX == "Female", ]

## probability of having at least one contact in the past 12 months by race
white.prob.contact2008 <- compute.prob(white2008$WEIGHT, white2008$V2 == "Yes", !is.na(white2008$V2))
black.prob.contact2008 <- compute.prob(black2008$WEIGHT, black2008$V2 == "Yes", !is.na(black2008$V2))
hisp.prob.contact2008 <- compute.prob(hisp2008$WEIGHT, hisp2008$V2 == "Yes", !is.na(hisp2008$V2))

## probability of having at least one contact in the past 12 months by sex
men.prob.contact2008 <- compute.prob(men2008$WEIGHT, men2008$V2 == "Yes", !is.na(men2008$V2))
women.prob.contact2008 <- compute.prob(women2008$WEIGHT, women2008$V2 == "Yes", !is.na(women2008$V2))

## mean number of contacts by race for people who had at least one contact
white.mean.contacts2008 <- weighted.mean(white2008$V3[white2008$V3 != 0], white2008$WEIGHT[white2008$V3 != 0], na.rm = TRUE)
black.mean.contacts2008 <- weighted.mean(black2008$V3[black2008$V3 != 0], black2008$WEIGHT[black2008$V3 != 0], na.rm = TRUE)
hisp.mean.contacts2008 <- weighted.mean(hisp2008$V3[hisp2008$V3 != 0], hisp2008$WEIGHT[hisp2008$V3 != 0], na.rm = TRUE)

## probability of having more than 3 contacts in the past 12 months by race for people who had at least one contact
white.prob.3contacts2008 <- compute.prob(white2008$WEIGHT, white2008$V3 > 3, !is.na(white2008$V3))
black.prob.3contacts2008 <- compute.prob(black2008$WEIGHT, black2008$V3 > 3, !is.na(black2008$V3))
hisp.prob.3contacts2008 <- compute.prob(hisp2008$WEIGHT, hisp2008$V3 > 3, !is.na(hisp2008$V3))

## probability that police used or threatened to use force during last contact for people who had at least one contact
white.prob.force2008 <- compute.prob(white2008$WEIGHT, white2008$V5 == "Yes", !is.na(white2008$V5))
black.prob.force2008 <- compute.prob(black2008$WEIGHT, black2008$V5 == "Yes", !is.na(black2008$V5))
hisp.prob.force2008 <- compute.prob(hisp2008$WEIGHT, hisp2008$V5 == "Yes", !is.na(hisp2008$V5))

## probability that police used or threatened to use force during last contact for people who had at least one contact
## broken down by sex instead of race
men.prob.force2008 <- compute.prob(men2008$WEIGHT, men2008$V5 == "Yes", !is.na(men2008$V5))
women.prob.force2008 <- compute.prob(women2008$WEIGHT, women2008$V5 == "Yes", !is.na(women2008$V5))

## probability that police used verbal force during last contact for people
## against whom the police used or threatened to use force
white.prob.verbal2008 <- compute.prob(white2008$WEIGHT,
                                      white2008$V6A == "Yes" | white2008$V6B == "Yes" | white2008$V6C == "Yes",
                                      !is.na(white2008$V6A) & !is.na(white2008$V6B) & !is.na(white2008$V6C))
black.prob.verbal2008 <- compute.prob(black2008$WEIGHT,
                                      black2008$V6A == "Yes" | black2008$V6B == "Yes" | black2008$V6C == "Yes",
                                      !is.na(black2008$V6A) & !is.na(black2008$V6B) & !is.na(black2008$V6C))
hisp.prob.verbal2008 <- compute.prob(hisp2008$WEIGHT,
                                     hisp2008$V6A == "Yes" | hisp2008$V6B == "Yes" | hisp2008$V6C == "Yes",
                                     !is.na(hisp2008$V6A) & !is.na(hisp2008$V6B) & !is.na(hisp2008$V6C))

## probability that police used physical force during last contact for people
## against whom the police used or threatened to use force
white.prob.physical2008 <- compute.prob(white2008$WEIGHT,
                                        white2008$V6D == "Yes" | white2008$V6E == "Yes" | white2008$V6F == "Yes" | white2008$V6G == "Yes" | white2008$V6H == "Yes",
                                        !is.na(white2008$V6D) & !is.na(white2008$V6E) & !is.na(white2008$V6F) & !is.na(white2008$V6G) & !is.na(white2008$V6H))
black.prob.physical2008 <- compute.prob(black2008$WEIGHT,
                                        black2008$V6D == "Yes" | black2008$V6E == "Yes" | black2008$V6F == "Yes" | black2008$V6G == "Yes" | black2008$V6H == "Yes",
                                        !is.na(black2008$V6D) & !is.na(black2008$V6E) & !is.na(black2008$V6F) & !is.na(black2008$V6G) & !is.na(black2008$V6H))
hisp.prob.physical2008 <- compute.prob(hisp2008$WEIGHT,
                                       hisp2008$V6D == "Yes" | hisp2008$V6E == "Yes" | hisp2008$V6F == "Yes" | hisp2008$V6G == "Yes" | hisp2008$V6H == "Yes",
                                       !is.na(hisp2008$V6D) & !is.na(hisp2008$V6E) & !is.na(hisp2008$V6F) & !is.na(hisp2008$V6G) & !is.na(hisp2008$V6G))

## probability that police used physical force during last contact for people
## against whom the police used or threatened to use force broken down by sex
men.prob.physical2008 <- compute.prob(men2008$WEIGHT,
                                        men2008$V6D == "Yes" | men2008$V6E == "Yes" | men2008$V6F == "Yes" | men2008$V6G == "Yes" | men2008$V6H == "Yes",
                                        !is.na(men2008$V6D) & !is.na(men2008$V6E) & !is.na(men2008$V6F) & !is.na(men2008$V6G) & !is.na(men2008$V6H))
women.prob.physical2008 <- compute.prob(women2008$WEIGHT,
                                        women2008$V6D == "Yes" | women2008$V6E == "Yes" | women2008$V6F == "Yes" | women2008$V6G == "Yes" | women2008$V6H == "Yes",
                                        !is.na(women2008$V6D) & !is.na(women2008$V6E) & !is.na(women2008$V6F) & !is.na(women2008$V6G) & !is.na(women2008$V6H))

## probability that respondent was injured during last contact for people who had at least one contact
## during which the police used or threatened to use force
white.prob.injured2008 <- compute.prob(white2008$WEIGHT, white2008$V8 == "Yes", !is.na(white2008$V8))
black.prob.injured2008 <- compute.prob(black2008$WEIGHT, black2008$V8 == "Yes", !is.na(black2008$V8))
hisp.prob.injured2008 <- compute.prob(hisp2008$WEIGHT, hisp2008$V8 == "Yes", !is.na(hisp2008$V8))

## probability that respondent was injured during last contact for people who had at least one contact
## during which the police used or threatened to use force broken down by sex instead of race
men.prob.injured2008 <- compute.prob(men2008$WEIGHT, men2008$V8 == "Yes", !is.na(men2008$V8))
women.prob.injured2008 <- compute.prob(women2008$WEIGHT, women2008$V8 == "Yes", !is.na(women2008$V8))

## calculate the average of the rates I computed for 2005 and 2008, as well as
## the corresponding unconditional probabilities

white.prob.contact <- (white.prob.contact2005 + white.prob.contact2008)/2
black.prob.contact <- (black.prob.contact2005 + black.prob.contact2008)/2
hisp.prob.contact <- (hisp.prob.contact2005 + hisp.prob.contact2008)/2

white.mean.contacts <- (white.prob.contact2005*white.mean.contacts2005 + white.prob.contact2008*white.mean.contacts2008)/2
black.mean.contacts <- (black.prob.contact2005*black.mean.contacts2005 + black.prob.contact2008*black.mean.contacts2008)/2
hisp.mean.contacts <- (hisp.prob.contact2005*hisp.mean.contacts2005 + hisp.prob.contact2008*hisp.mean.contacts2008)/2

white.prob.3contacts <- (white.prob.contact2005*white.prob.3contacts2005 + white.prob.contact2008*white.prob.3contacts2008)/2
black.prob.3contacts <- (black.prob.contact2005*black.prob.3contacts2005 + black.prob.contact2008*black.prob.3contacts2008)/2
hisp.prob.3contacts <- (hisp.prob.contact2005*hisp.prob.3contacts2005 + hisp.prob.contact2008*hisp.prob.3contacts2008)/2

white.prob.force <- (white.prob.force2005 + white.prob.force2008)/2
black.prob.force <- (black.prob.force2005 + black.prob.force2008)/2
hisp.prob.force <- (hisp.prob.force2005 + hisp.prob.force2008)/2

white.uncond.prob.force <- (white.prob.contact2005*white.prob.force2005 + white.prob.contact2008*white.prob.force2008)/2
black.uncond.prob.force <- (black.prob.contact2005*black.prob.force2005 + black.prob.contact2008*black.prob.force2008)/2
hisp.uncond.prob.force <- (hisp.prob.contact2005*hisp.prob.force2005 + hisp.prob.contact2008*hisp.prob.force2008)/2

white.prob.verbal <- (white.prob.force2005*white.prob.verbal2005 + white.prob.force2008*white.prob.verbal2008)/2
black.prob.verbal <- (black.prob.force2005*black.prob.verbal2005 + black.prob.force2008*black.prob.verbal2008)/2
hisp.prob.verbal <- (hisp.prob.force2005*hisp.prob.verbal2005 + hisp.prob.force2008*hisp.prob.verbal2008)/2

white.uncond.prob.verbal <- (white.prob.contact2005*white.prob.force2005*white.prob.verbal2005 + white.prob.contact2008*white.prob.force2008*white.prob.verbal2008)/2
black.uncond.prob.verbal <- (black.prob.contact2005*black.prob.force2005*black.prob.verbal2005 + black.prob.contact2008*black.prob.force2008*black.prob.verbal2008)/2
hisp.uncond.prob.verbal <- (hisp.prob.contact2005*hisp.prob.force2005*hisp.prob.verbal2005 + hisp.prob.contact2008*hisp.prob.force2008*hisp.prob.verbal2008)/2

white.prob.physical <- (white.prob.force2005*white.prob.physical2005 + white.prob.force2008*white.prob.physical2008)/2
black.prob.physical <- (black.prob.force2005*black.prob.physical2005 + black.prob.force2008*black.prob.physical2008)/2
hisp.prob.physical <- (hisp.prob.force2005*hisp.prob.physical2005 + hisp.prob.force2008*hisp.prob.physical2008)/2

white.uncond.prob.physical <- (white.prob.contact2005*white.prob.force2005*white.prob.physical2005 + white.prob.contact2008*white.prob.force2008*white.prob.physical2008)/2
black.uncond.prob.physical <- (black.prob.contact2005*black.prob.force2005*black.prob.physical2005 + black.prob.contact2008*black.prob.force2008*black.prob.physical2008)/2
hisp.uncond.prob.physical <- (hisp.prob.contact2005*hisp.prob.force2005*hisp.prob.physical2005 + hisp.prob.contact2008*hisp.prob.force2008*hisp.prob.physical2008)/2

white.prob.injured <- (white.prob.force2005*white.prob.injured2005 + white.prob.force2008*white.prob.injured2008)/2
black.prob.injured <- (black.prob.force2005*black.prob.injured2005 + black.prob.force2008*black.prob.injured2008)/2
hisp.prob.injured <- (hisp.prob.force2005*hisp.prob.injured2005 + hisp.prob.force2008*hisp.prob.injured2008)/2

white.uncond.prob.injured <- (white.prob.contact2005*white.prob.force2005*white.prob.injured2005 + white.prob.contact2008*white.prob.force2008*white.prob.injured2008)/2
black.uncond.prob.injured <- (black.prob.contact2005*black.prob.force2005*black.prob.injured2005 + black.prob.contact2008*black.prob.force2008*black.prob.injured2008)/2
hisp.uncond.prob.injured <- (hisp.prob.contact2005*hisp.prob.force2005*hisp.prob.injured2005 + hisp.prob.contact2008*hisp.prob.force2008*hisp.prob.injured2008)/2

men.uncond.prob.force <- (men.prob.contact2005*men.prob.force2005 + men.prob.contact2008*men.prob.force2008)/2
women.uncond.prob.force <- (women.prob.contact2005*women.prob.force2005 + women.prob.contact2008*women.prob.force2008)/2

men.uncond.prob.physical <- (men.prob.contact2005*men.prob.force2005*men.prob.physical2005 + men.prob.contact2008*men.prob.force2008*men.prob.physical2008)/2
women.uncond.prob.physical <- (women.prob.contact2005*women.prob.force2005*women.prob.physical2005 + women.prob.contact2008*women.prob.force2008*women.prob.physical2008)/2

men.uncond.prob.injured <- (men.prob.contact2005*men.prob.force2005*men.prob.injured2005 + men.prob.contact2008*men.prob.force2008*men.prob.injured2008)/2
women.uncond.prob.injured <- (women.prob.contact2005*women.prob.force2005*women.prob.injured2005 + women.prob.contact2008*women.prob.force2008*women.prob.injured2008)/2

## draw the various graphs for the article

races <- c("Whites", "Blacks", "Hispanics")
colors <- c("dodgerblue2","indianred", "yellowgreen")

barplot(c(white.prob.contact, black.prob.contact, hisp.prob.contact),
        main = "Probability of having at least one contact per year",
        names.arg = races,
        ylim = c(0, 0.25),
        space = 0.1,
        col = colors)

barplot(c(white.mean.contacts, black.mean.contacts, hisp.mean.contacts),
        main = "Mean number of contacts per year",
        names.arg = races,
        ylim = c(0, 0.4),
        space = 0.1,
        col = colors)

barplot(c(white.prob.3contacts, black.prob.3contacts, hisp.prob.3contacts),
        main = "Probability of having more than 3 contacts per year",
        names.arg = races,
        ylim = c(0, 0.02),
        space = 0.1,
        col = colors)

barplot(c(white.prob.force, black.prob.force, hisp.prob.force),
        main = "Probability that force was used or threatened against \nmen who had at least one contact",
        names.arg = races,
        ylim = c(0, 0.06),
        space = 0.1,
        col = colors)

barplot(c(white.uncond.prob.force, black.uncond.prob.force, hisp.uncond.prob.force),
        main = "Probability that force was used or threatened",
        names.arg = races,
        ylim = c(0, 0.01),
        space = 0.1,
        col = colors)

barplot(c(white.prob.verbal, black.prob.verbal, hisp.prob.verbal),
        main = "Probability that purely verbal force was used \nagainst men who had at least one contact",
        names.arg = races,
        ylim = c(0, 0.05),
        space = 0.1,
        col = colors)

barplot(c(white.uncond.prob.verbal, black.uncond.prob.verbal, hisp.uncond.prob.verbal),
        main = "Probability that purely verbal force was used",
        names.arg = races,
        ylim = c(0, 0.008),
        space = 0.1,
        col = colors)

barplot(c(white.prob.physical, black.prob.physical, hisp.prob.physical),
        main = "Probability that physical force was used against \nmen who had at least one contact",
        names.arg = races,
        ylim = c(0, 0.035),
        space = 0.1,
        col = colors)

barplot(c(white.uncond.prob.physical, black.uncond.prob.physical, hisp.uncond.prob.physical),
        main = "Probability that physical force was used",
        names.arg = races,
        ylim = c(0, 0.006),
        space = 0.1,
        col = colors)

barplot(c(white.prob.injured, black.prob.injured, hisp.prob.injured),
        main = "Probability that a man who had at least \none contact was injured",
        names.arg = races,
        ylim = c(0, 0.005),
        space = 0.1,
        col = colors)

barplot(c(white.uncond.prob.injured, black.uncond.prob.injured, hisp.uncond.prob.injured),
        main = "Probability that a man was injured",
        names.arg = races,
        ylim = c(0, 0.001),
        space = 0.1,
        col = colors)

barplot(c(men.uncond.prob.physical, women.uncond.prob.physical),
        main = "Probability that physical force was used",
        names.arg = c("Men", "Women"),
        ylim = c(0, 0.0025),
        space = 0.1,
        col = c("dodgerblue2","indianred"))
